# Moving Stimulus Responses

## Rendering

::: flyvis.datasets.moving_bar.RenderedOffsets

## Datasets

::: flyvis.datasets.moving_bar.MovingBar

::: flyvis.datasets.moving_bar.MovingEdge

## Response Analysis

::: flyvis.analysis.moving_bar_responses

## Current Analysis

::: flyvis.analysis.moving_edge_currents.MovingEdgeCurrentView
